@@ -5,6 +5,7 @@ use strict;
 use warnings;
 use Carp;
 use File::Path qw(make_path);
+use IPC::Cmd qw(can_run);
 use File::Copy;
 use File::TVShow::Info;
 
@@ -12,7 +13,7 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 # Preloaded methods go here.
 
@@ -222,7 +223,7 @@ sub were_there_errors {
   # Check if there has been any files that File::TVShow::Info could not handle
   # Check that the hash UnHandledFileNames has actually been created before
   # checking that is is not empty or you will get an error.
-  if ((defined $self->{UnhandledFileNames}) && (keys $self->{UnhandledFileNames})) {
+  if ((defined $self->{UnhandledFileNames}) && (keys %{$self->{UnhandledFileNames}})) {
     print "\nThere were unhandled files in the directory\n";
     print "consider adding them to the exceptionList\n###\n";
     foreach my $key (keys %{$self->{UnhandledFileNames}}) {
@@ -358,7 +359,10 @@ sub move_show {
 
   # create the command string to be used in system() call
   # Set --progress if verbose is true
-  my $command = "rsync -ta ";
+
+  # Get path to rsync using IPC::Cmd
+  my $command = can_run('rsync');
+  $command .=  " -ta ";
   $command = $command . "--progress " if ($self->verbose);
   $command = $command . $source . $file . " " . $destination;
 
@@ -412,7 +416,7 @@ matching Show Folder on a media server.
 
 =head1 VERSION
 
-VERSION 0.34
+VERSION 0.35
 
 =head1 SYNOPSIS
 
